{% extends "bee_django_report/base.html" %}
{% block content %}
    {% include 'bee_django_report/logo.html' %}
    {% include 'bee_django_report/nav.html' %}
    <h4>会员统计</h4>
    <div><a href="{% url 'bee_django_report:user_gender' %}">性别饼图</a></div>
    <div><a href="{% url 'bee_django_report:user_age' %}">年龄饼图</a></div>
    <div><a href="{% url 'bee_django_report:class_week' class_id=1 %}">班级周报</a></div>



{% endblock %}
