# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-07-25 07:46
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='ClassWeek',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('class_id', models.IntegerField(null=True, verbose_name='\u73ed\u7ea7id')),
                ('year', models.IntegerField()),
                ('week', models.IntegerField(null=True)),
                ('type_int', models.IntegerField(default=0)),
                ('start_date', models.DateField()),
                ('end_date', models.DateField()),
                ('live_mins', models.IntegerField()),
                ('feed_count', models.IntegerField()),
                ('live_days', models.IntegerField()),
                ('live_count', models.IntegerField()),
                ('last_user_section_id', models.IntegerField(null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True, null=True)),
                ('mentor', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='classWeek_mentor', to=settings.AUTH_USER_MODEL)),
                ('user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='classWeek_student', to=settings.AUTH_USER_MODEL, verbose_name='\u5b66\u751f')),
            ],
            options={
                'ordering': ['created_at'],
                'db_table': 'bee_django_report_class_week',
            },
        ),
        migrations.CreateModel(
            name='mentorScore',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('year', models.IntegerField()),
                ('week', models.IntegerField(null=True)),
                ('score', models.FloatField(null=True)),
                ('rank', models.IntegerField(null=True)),
                ('level', models.IntegerField(null=True)),
                ('info', models.TextField(null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('mentor', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['created_at'],
                'db_table': 'bee_django_report_montor_score',
            },
        ),
    ]
