<div id="main" style="width: 100%;height:600px;margin-top: 20px;"></div>
{% block scripts %}
    {#    <script src="/static/echart/map_china.js"></script>#}

    <script type="text/javascript">

        $(document).ready(function () {
            var myChart = echarts.init(document.getElementById('main'));
            var option = {
                title: {
                    text: '{{ title }}',
                    subtext: '{{ subtext }}',
                    left: 'center'
                },
                tooltip: {
                    trigger: 'item',
                    formatter: "{b} : {c} ({d}%)"
                },
                series: {
                    type: 'pie',

                    data: {{ data_list|safe }}
                }

            };
            myChart.setOption(option);

        });


    </script>

{% endblock %}