<style>
    .nav {
        background-color: #4B6788;
        height: 40px;
        color: #ffffff;
        line-height: 40px;
        padding: 0 10px;
    }

    .nav a {
        color: #ffffff;
    }
</style>
<div class="nav">
    <a href="{% url 'bee_django_report:index' %}">统计页</a>

</div>