{% extends "bee_django_report/base.html" %}
{% block content %}
    {% include 'bee_django_report/logo.html' %}
    {% include 'bee_django_report/nav.html' %}
    {% include 'bee_django_report/report/echart/pie.html' %}

{% endblock %}
